<div align="center">
	<img alt="Digest Crane" src="https://gitlab.com/digested/node-digest/raw/master/packages/webpack/share/favicon.png" />
</div><br>

<div align="center">
	<h1>@digest/scripts</h1>
</div>

<div align="center">
<a href="https://commitizen.github.io/cz-cli/"><img alt="Commitizen Friendly" src="https://img.shields.io/badge/commitizen-friendly-brightgreen.svg?maxAge=2592000" /></a>
<a href="https://github.com/semantic-release/semantic-release"><img alt="Semantic Release" src="https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg?maxAge=2592000" /></a>
</div>

<div align="center">
<a href="https://gitlab.com/digested/node-digest/commits/master"><img alt="Build Status" src="https://gitlab.com/digested/node-digest/badges/master/build.svg" /></a>
<a href="https://digested.gitlab.io/node-digest/coverage"><img alt="Coverage Report" src="https://gitlab.com/digested/node-digest/badges/master/coverage.svg" /></a>
<a href="https://www.npmjs.org/package/@digest/webpack"><img alt="NPM Version" src="http://img.shields.io/npm/v/digest.svg?maxAge=86400" /></a>
<a href="https://www.gnu.org/licenses/gpl-3.0.en.html"><img alt="License" src="https://img.shields.io/npm/l/digest.svg?maxAge=2592000" /></a>
<a href="https://github.com/gajus/canonical"><img alt="Canonical Code Style" src="https://img.shields.io/badge/code%20style-canonical-blue.svg?maxAge=2592000" /></a>
</div>

<h2> </h2>

**@digest/scripts** shared scripts for the other `@digest` projects to function.
These include a configuration loader to catch the following user parameters and
a resolver to properly require various default and user determined files.

*This package should not need to be required explicitly.*

This is the master list of managed properties.

| digest.config.js          | Environment Variable      | Description                                                                                                                                                                                                                                   | Default                                                                                                                                      | Options                                      |
|---------------------------|---------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------|
| *n/a*                     | **NODE_ENV**              | Use either **production** or **development**. Production features include minification, while development features include linting and HMR.                                                                                                   | `production`                                                                                                                                 | <code>\[production&#124;development\]</code> |
| *n/a*                     | DIGEST                    | Path to `@digest` settings. It contains these settings and [more](https://www.npmjs.com/package/@digest/scripts).                                                                                                                             | `/digest.config.js`                                                                                                                          |                                              |
| *n/a*                     | PORT                      | The express host port                                                                                                                                                                                                                         | Default `8080`, `8090` when `NODE_ENV='development'`                                                                                         |                                              |
| angular                   | ANGULAR                   | Enable/Disable [`Angular`](https://angular.io/) required Babel plugins, Webpack loaders, and library entries                                                                                                                                  | `true` if `@digest/angular` is included in `package.json` dependencies; otherwise `false`                                                    | <code>\[true&#124;false\]</code>             |
| appHost                   | APP_HOST                  | The express server host                                                                                                                                                                                                                       | default `host` value                                                                                                                         |                                              |
| babel                     | BABEL                     | Path to [`Babel configuration file`](https://babeljs.io/docs/en/babelrc) or `false` to disable                                                                                                                                                | `/.babelrc`, or `@digest/babel` provided configuration file if included in `package.json` dependencies, otherwise `false`                    | <code>\[PATH&#124;false\]</code>             |
| baseHref                  | BASE_HREF                 | Set the provided default `index.html` base href path, e.g. `<base href=''>`. Also used by provided express and workbox configs.                                                                                                               | `/`                                                                                                                                          |                                              |
| cache                     | CACHE                     | Path to store temporary cache files                                                                                                                                                                                                           | `/node_modules/.cache/`                                                                                                                      |                                              |
| compression               | COMPRESSION               | Enable file compression and attempt to serve compressed files.                                                                                                                                                                                | `true`                                                                                                                                       | <code>\[true&#124;false\]</code>             |
| config                    | CONFIG                    | Path to Webpack config.                                                                                                                                                                                                                       | `/webpack.config.js`, or `@digest/webpack` provided config                                                                                   |                                              |
| cssModules                | CSS_MODULES               | Enables CSS modules in Webpack and Babel                                                                                                                                                                                                      | `false`                                                                                                                                      | <code>\[true&#124;false\]</code>             |
| dashboard                 | DASHBOARD                 | Use `webpack-dashboard`                                                                                                                                                                                                                       | `true`                                                                                                                                       | <code>\[true&#124;false\]</code>             |
| e2e                       | E2E                       | Path to end-to-end test files for Nightwatch                                                                                                                                                                                                  | `/__e2e__`                                                                                                                                   |                                              |
| env                       | ENV                       | A `json` object that defines environment variables to be included by Webpack DefinePlugin. For example, `{"open": "\"sets\""}`. Accessible under `process.env`.                                                                               | `{}`                                                                                                                                         |                                              |
| eslint                    | ESLINT                    | Path to JavaScript [ESLint configuration file](https://eslint.org/docs/user-guide/configuring)                                                                                                                                                | `/.eslintrc`, or `@digest/eslint-config` provided configuration file if included in `package.json` dependencies, otherwise `false`           | <code>\[PATH&#124;false\]</code>             |
| favicon                   | FAVICON                   | Path to `favicon.png`                                                                                                                                                                                                                         | `/SRC_PATH/favicon.png` or default favicon packaged with `@digest/webpack`                                                                   |                                              |
| flow                      | FLOW                      | Enable/Disable [`FlowType`](https://flow.org/) Babel [preset](https://www.npmjs.com/package/@babel/preset-flow)                                                                                                                               | `true` if `@digest/flow` is included in `package.json` dependencies; otherwise `false`                                                       | <code>\[true&#124;false\]</code>             |
| graphql                   | GRAPHQL                   | Enable/Disable [`GraphQL`](https://graphql.org/) Babel [`plugin`](https://www.npmjs.com/package/babel-plugin-graphql-tag) and Webpack file [`loader`](https://www.npmjs.com/package/graphql-tag#webpack-preprocessing-with-graphql-tagloader) | `true` if `@digest/graphql` is included in `package.json` dependencies; otherwise `false`                                                    | <code>\[true&#124;false\]</code>             |
| graphqlSchema             | GRAPHQL_SCHEMA            | Path to GraphQL `schema.json`                                                                                                                                                                                                                 | `/schema.json`                                                                                                                               |                                              |
| headless                  | HEADLESS                  | Whether to run browsers in headless mode in `selenium`                                                                                                                                                                                        | `true`                                                                                                                                       | <code>\[true&#124;false\]</code>             |
| host                      | HOST                      | The default host                                                                                                                                                                                                                              | `127.0.0.1`                                                                                                                                  |                                              |
| index                     | INDEX                     | Path to `index.htm`                                                                                                                                                                                                                           | `/SRC_PATH/index.htm` or default `index.htm` packaged with `@digest/webpack`                                                                 |                                              |
| jestSetup                 | JEST_SETUP                | Path to [Jest](https://jestjs.io/) [`setup file`](https://jestjs.io/docs/en/configuration.html#setupfiles-array)                                                                                                                              | `/jest.setup.json`, or `@digest/jest` provided configuration file if included in `package.json` dependencies                                 |                                              |
| library                   | LIBRARY                   | Toggle UMD library creation instead. This generates a bundle *without* dependencies and polyfills                                                                                                                                             | `false`                                                                                                                                      | <code>\[true&#124;false\]</code>             |
| minimize                  | MINIMIZE                  | Enable/Disable minification. Can be useful when wanting to both copies for publishing.                                                                                                                                                        | `true`                                                                                                                                       | <code>\[true&#124;false\]</code>             |
| parallel                  | PARALLEL                  | Whether to run loaders in parallel or not. Parallel will only use the maximum processors minus two; but can be disabled altogether if issues still arise                                                                                      | `true`                                                                                                                                       | <code>\[true&#124;false\]</code>             |
| polyfills                 | POLYFILLS                 | Path to additional polyfills                                                                                                                                                                                                                  | `/polyfills.js`                                                                                                                              |                                              |
| postcss                   | POSTCSS                   | Path to [PostCSS](https://github.com/postcss/postcss#webpack) config                                                                                                                                                                          | `/postcss.config.js`, or `@digest/postcss` provided configuration file if included in `package.json` dependencies, otherwise `false`         | <code>\[PATH&#124;false\]</code>             |
| postcssWhitelist          | POSTCSS_WHITELIST         | A pipe separated whitelist of packages in `node_modules` that *should* be parsed by PostCSS                                                                                                                                                   | `react-toolbox`                                                                                                                              |                                              |
| pwa                       | PWA                       | Includes [`Workbox`](https://developers.google.com/web/tools/workbox/) entries in Webpack build                                                                                                                                               | `true` if `@digest/webpack-workbox` is included in `package.json` dependencies; otherwise `false`                                            | <code>\[true&#124;false\]</code>             |
| react                     | REACT                     | Enable/Disable [`React`](https://reactjs.org/) Babel [`preset`](https://www.npmjs.com/package/@babel/preset-react) and other related plugins                                                                                                  | `true` if `@digest/react` is included in `package.json` dependencies; otherwise `false`                                                      | <code>\[true&#124;false\]</code>             |
| reportPath                | REPORT_PATH               | Path to generate reports                                                                                                                                                                                                                      | `/reports`                                                                                                                                   |                                              |
| scss                      | SCSS                      | Enable/Disable [`SCSS`](https://sass-lang.com/) Webpack [loader](https://www.npmjs.com/package/sass-loader)                                                                                                                                   | `true` if `@digest/scss` is included in `package.json` dependencies; otherwise `false`                                                       | <code>\[true&#124;false\]</code>             |
| seleniumChromeDriver      | SELENIUM_CHROME_DRIVER    | The Selenium Chrome driver version                                                                                                                                                                                                            |                                                                                                                                              |                                              |
| seleniumDriver            | SELENIUM_DRIVER           | The Selenium driver version                                                                                                                                                                                                                   |                                                                                                                                              |                                              |
| seleniumGeckoDriver       | SELENIUM_GECKO_DRIVER     | The Selenium Firefox/Gecko driver version                                                                                                                                                                                                     |                                                                                                                                              |                                              |
| seleniumHost              | SELENIUM_HOST             | The Selenium server host                                                                                                                                                                                                                      | default `host` value                                                                                                                         |                                              |
| seleniumPort              | SELENIUM_PORT             | The Selenium server port                                                                                                                                                                                                                      | `4444`                                                                                                                                       |                                              |
| seleniumStart             | SELENIUM_START            | Whether to start Selenium or not; for CI integration.                                                                                                                                                                                         | `true`                                                                                                                                       |                                              |
| shortName                 | SHORT_NAME                | An optional shorter name to be used in bundle generation. Useful when generating libraries.                                                                                                                                                   | The `name` property in `package.json`                                                                                                        |                                              |
| sourceMaps                | SOURCE_MAPS               | Toggle source map generation                                                                                                                                                                                                                  | `true`                                                                                                                                       | <code>\[true&#124;false\]</code>             |
| srcPath                   | SRC_PATH                  | Path to project files directory relative to project root                                                                                                                                                                                      | `/src`                                                                                                                                       |                                              |
| staticPath                | STATIC_PATH               | Path to directory where Webpack will deposit the resulting project relative to project root                                                                                                                                                   | `/public`                                                                                                                                    |                                              |
| stylelint                 | STYLELINT                 | Path to CSS [`stylelint configuration file`](https://stylelint.io/user-guide/configuration/) or `false` to disable                                                                                                                            | `/.stylelintrc`, or `@digest/stylelint-config` provided configuration file if included in `package.json` dependencies, otherwise `false`     | <code>\[PATH&#124;false\]</code>             |
| stylelintIgnore           | STYLELINT_IGNORE          | Path to CSS [`stylelint ignore file`](https://stylelint.io/user-guide/configuration/#ignorefiles)                                                                                                                                             | `/.stylelintignore` or default `.stylelintignore` packaged with `@digest/stylelint-config`                                                   |                                              |
| typescript                | TYPESCRIPT                | Path to [TypeScript configuration file](https://www.typescriptlang.org/docs/handbook/tsconfig-json.html) or `false` to disable                                                                                                                | `/tsconfig.json`, or `@digest/typescript` provided configuration file if included in `package.json` dependencies, otherwise `false`          | <code>\[PATH&#124;false\]</code>             |


## License

GPLv3
